@@ -26,6 +26,12 @@ has timeout => (
     default => sub { 30 },
 );
 
+has tls => (
+    is => 'ro',
+    isa => 'Bool',
+    default => sub { 0 },
+);
+
 has verbose => (
     is => 'ro',
     isa => 'Bool',
@@ -46,6 +52,7 @@ sub _build_connection {
         user       => $self->username,
         pass       => $self->password,
         vhost      => $self->vhost,
+        tls        => $self->tls,
         timeout    => $self->timeout,
         on_success => sub {
             $self->_set_connected(1);
@@ -66,3 +73,30 @@ sub _build_connection {
 __PACKAGE__->meta->make_immutable;
 1;
 
+=head1 NAME
+
+Message::Passing::AMQP::ConnectionManager - Implements the Message::Passing::Role::HasAConnection interface.
+
+=head1 ATTRIBUTES
+
+=head2 vhost
+
+Passed to L<AnyEvent::RabbitMQ>->new->connect.
+
+=head2 timeout
+
+Passed to L<AnyEvent::RabbitMQ>->new->connect.
+
+=head2 tls
+
+Passed to L<AnyEvent::RabbitMQ>->new->connect.
+
+=head2 verbose
+
+Passed to L<AnyEvent::RabbitMQ>->new.
+
+=head1 AUTHOR, COPYRIGHT AND LICENSE
+
+See L<Message::Passing::AMQP>.
+
+=cut
